import { http } from '@/utils/http'
import type { EimsEquStatuVO, EimsEquStatuBo } from './equ_status.d'

/**
 * 查询设备状态记录列表
 */
export const getEquStatuList = (params: EimsEquStatuBo & { pageNum?: number; pageSize?: number }) => {
  return http.get<{ rows: EimsEquStatuVO[], total: number }>('/eims/equStatu/list', params)
}

/**
 * 获取设备状态记录详细信息
 * @param equStatuId 主键
 */
export const getEquStatuInfo = (equStatuId: number | string) => {
  return http.get<EimsEquStatuVO>(`/eims/equStatu/${equStatuId}`)
}

/**
 * 新增设备状态记录
 */
export const addEquStatu = (data: EimsEquStatuBo) => {
  return http.post('/eims/equStatu', data)
}

/**
 * 修改设备状态记录
 */
export const updateEquStatu = (data: EimsEquStatuBo) => {
  return http.put('/eims/equStatu', data)
}

/**
 * 删除设备状态记录
 * @param equStatuIds 主键串
 */
export const deleteEquStatu = (equStatuIds: (number | string)[]) => {
  return http.delete(`/eims/equStatu/${equStatuIds.join(',')}`)
}

/**
 * 导出设备状态记录列表
 */
export const exportEquStatu = (params: EimsEquStatuBo) => {
  return http.post('/eims/equStatu/export', params, {
    responseType: 'blob'
  })
}